<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://habibridho.github.io
 * @since      1.0.0
 *
 * @package    Biteship
 * @subpackage Biteship/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Biteship
 * @subpackage Biteship/admin
 * @author     Habib <habibridho@live.com>
 */
class Biteship_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Biteship_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Biteship_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/biteship-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Biteship_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Biteship_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/biteship-admin.js', array( 'jquery' ), $this->version, false );

	}

	public function on_loaded() {
		// add_action('admin_menu', array($this, 'menu'));
	}

	public function menu() {
		add_menu_page("Biteship", "Biteship", "manage_woocommerce", "biteship", array($this, 'render_admin_home_page'), null, '55.6');
	}

	public function render_admin_home_page() {
		include_once plugin_dir_path( __FILE__ ) . "views/home.php";
	}

}
