<?php

class Biteship_Rest_Adapter {
    public function __construct($license_key)
    {
        $this->license_key = $license_key;
        $this->base_url = 'https://api.weareswift.com';
    }

    private function http_get($url) {
        $args = array(
            'headers' => array(
                'authorization' => 'Bearer ' . $this->license_key,
            ),
        );

        $response = wp_remote_get($url, $args);
        if ( is_wp_error($response) ) {
            return __( 'Something went wrong, please try again', 'biteship' );
        }

        return json_decode( wp_remote_retrieve_body($response), true );
    }

    private function http_post($url, $body) {
        $args = array(
            'body' => json_encode($body),
            'headers' => array(
                'authorization' => 'Bearer ' . $this->license_key,
                'content-type' => 'application/json'
            ),
        );

        $response = wp_remote_post($url, $args);
        if ( is_wp_error($response) ) {
            return __( 'Something went wrong, please try again', 'biteship' );
        }

        return json_decode( wp_remote_retrieve_body($response), true );
    }

    public function get_pricing($query) {
        $requested_services = $query['requested_services'];
        $url = $this->base_url . '/v1/pricing/couriers';

        $origin_latitude = null;
        $origin_longitude = null;
        $destination_latitude = null;
        $destination_longitude = null;
        if ( $query['origin_latitude'] != '' && $query['origin_longitude'] != '' && $query['destination_latitude'] != '' && $query['destination_longitude'] != '' ) {
            $origin_latitude = $query['origin_latitude'];
            $origin_longitude = $query['origin_longitude'];
            $destination_latitude = $query['destination_latitude'];
            $destination_longitude = $query['destination_longitude'];
        }
        $body = array(
            'origin_latitude' => $origin_latitude,
            'origin_longitude' => $origin_longitude,
            'destination_latitude' => $destination_latitude,
            'destination_longitude' => $destination_longitude,
            'origin_postal_code' => $query['origin_postal_code'],
            'destination_postal_code' => $query['destination_postal_code'],
            'couriers' => implode(',', $query['couriers']),
            'items' => array(),
        );

        foreach($query['items'] as $item) {
            array_push($body['items'], array(
                'name' => $item['name'],
                'length' => $item['length'],
                'width' => $item['width'],
                'height' => $item['height'],
                'weight' => $item['weight'],
                'quantity' => $item['quantity'],
                'value' => $item['value']
            ));
        }

        $data = $this->http_post($url, $body);
        if (!is_array($data)) {
            return $data;
        }

        if (!$data["success"]) {
            return $data['error'];
        }

        $result = array();
        foreach($data['pricing'] as $pricing) {
            $service_code = $pricing['courier_code'] . '/' . $pricing['courier_service_code'];
            if (in_array($service_code, $requested_services)) {
                $company = $pricing['courier_name'];
                $service_name = $pricing['courier_service_name'];
                $duration = $pricing['duration'];
                $price = $pricing['price'];
                array_push($result, array(
                    'id' => $service_code,
                    'label' => $company . '-' . $service_name . ' (' . $duration . ') ' ,
                    'cost' => $price,
                ));
            }
        }

        return $result;
    }

    public function get_couriers() {
        $url = $this->base_url . '/v1/couriers';
        $data = $this->http_get($url);
        if (!is_array($data)) {
            return $data;
        }

        if (!$data["success"]) {
            return __( 'Please get api key first.', 'biteship' );
        }

        $couriers_raw = $data["couriers"];

        $couriers = [];
        foreach($couriers_raw as $raw) {
            $courier_code = $raw["courier_code"];
            if (!array_key_exists($courier_code, $couriers)) {
                $couriers[$courier_code] = array(
                    "name" => $raw["courier_name"],
                    "code" => $raw["courier_code"],
                    "services" => [],
                );
            }
            array_push($couriers[$courier_code]["services"], array(
                "name" => $raw["courier_service_name"],
                "code" => $raw["courier_service_code"],
                "tier" => $raw["tier"],
                "description" => $raw["description"],
                "service_type" => $raw["service_type"],
                "shipping_type" => $raw["shipping_type"],
                "shipment_duration_range" => $raw["shipment_duration_range"],
                "shipment_duration_unit" => $raw["shipment_duration_unit"],
            ));
        }
        
        return $couriers;
    }
}