<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://habibridho.github.io
 * @since      1.0.0
 *
 * @package    Biteship
 * @subpackage Biteship/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Biteship
 * @subpackage Biteship/public
 * @author     Habib <habibridho@live.com>
 */
class Biteship_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Biteship_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Biteship_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/biteship-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Biteship_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Biteship_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/biteship-public.js', array( 'jquery' ), $this->version, false );

		$shipping_methods = WC()->shipping()->get_shipping_methods();
		$biteship_shipping = $shipping_methods['biteship'];
		$gmap_api_key = "";
		$message_var = "";
		if ($biteship_shipping != null) {
			$gmap_api_key = $biteship_shipping->settings['gmap_api_key'];
			$biteship_options = $biteship_shipping->get_options();
			$shipping_service_enabled = $biteship_options['shipping_service_enabled'];
			if ( !is_array($shipping_service_enabled ) ) {
				$shipping_service_enabled = array();
			}
			$has_gojek = false;
			$has_grab = false;
			foreach($shipping_service_enabled as $service) {
				$courier = explode("/", $service)[0];
				if ($courier == "gojek") {
					$has_gojek = true;
				} else if ($courier == "grab") {
					$has_grab = true;
				}
			}

			if ($has_gojek && $has_grab) {
				$message_var = "Gojek/Grab";
			} else if ($has_gojek) {
				$message_var = "Gojek";
			} else if ($has_grab) {
				$message_var = "Grab";
			}
		}
		$data = array(
			'apiKey' => $gmap_api_key,
			'courier' => $message_var,
		);
		wp_localize_script( $this->plugin_name, 'phpVars', $data );

	}

}
