(function( $ ) {
	'use strict';

	/**
	 * All of the code for your public-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */

  $(function() {
    $('body').append(`<div id="myModal" class="modal">
      <div class="modal-content">
        <span class="close">&times;</span>
        <legend>Close the map if you have pinned the map to calculate ${phpVars.courier} shipping rate</legend>
        <div id="map" class="map-order-review"></div>
      </div>
    </div>`);

    var marker = null
    var apiKey = phpVars ? phpVars.apiKey : '';
    $.getScript('https://maps.googleapis.com/maps/api/js?key=' + apiKey, function() {
      var myLatLng = {lat: -6.1753871, lng: 106.8249641};
      var map = new google.maps.Map(
        document.getElementById('map'), {
          zoom: 15, 
          center: myLatLng,
          disableDefaultUI: true,
          fullscreenControl: true
        }
      );
      marker = new google.maps.Marker({
      position: null,
      map: null,
      title: 'Location'
      })
      map.addListener('click', function(mapsMouseEvent) {
        var selectedPosition = mapsMouseEvent.latLng
        if (marker != null ) {
          marker.setPosition(selectedPosition)
          marker.setMap(map)
        }
        $('#position').val(selectedPosition.lat() + ',' + selectedPosition.lng());
      });
    });

    var modal = $('#myModal')
    var close = $('.close')
    var button = $("#mapButton")
    if (button.length > 0) {
      button[0].addEventListener("click", function() {
        modal.css('display', 'block')
      })
    }
    if (close.length > 0) {
      close[0].addEventListener("click", function() {
        modal.css('display', 'none')
        $(document.body).trigger( 'update_checkout' );
      })
    }
  })

})( jQuery );
